abacusai.embedding_feature_drift_distribution — AbacusAI documentation

# `abacusai.embedding_feature_drift_distribution`

## Module Contents

### Classes

`EmbeddingFeatureDriftDistribution` | Feature distribution for embeddings

class abacusai.embedding_feature_drift_distribution.EmbeddingFeatureDriftDistribution(client, distance=None, jsDistance=None, wsDistance=None, ksStatistic=None, averageDrift={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Feature distribution for embeddings

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - distance (list) – Histogram data of KL divergences between the training distribution and the range of values in the specified window.

    - jsDistance (list) – Histogram data of JS divergence between the training distribution and the range of values in the specified window.

    - wsDistance (list) – Histogram data of Wasserstein distance between the training distribution and the range of values in the specified window.

    - ksStatistic (list) – Histogram data of Kolmogorov-Smirnov statistic computed between the training distribution and the range of values in the specified window.

    - averageDrift (DriftTypesValue) – Average drift embedding for each type of drift

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict